@@ -12,6 +12,8 @@ import urllib.parse
 
 from datetime import datetime, timedelta
 
+from seedftw.base.timeseries import format_to_timetable
+
 # For caching
 from functools import lru_cache
 
@@ -37,42 +39,47 @@ def __dk_energinet_dataservice_call(sql_query, output_format="Dataframe"):
     return api_data
 
 
-def __date2api_format(datetime2use):
-    return datetime2use.strftime("%Y-%m-%dT%H:%M:%SZ")
+def __format_time(t_in):
+    if isinstance(t_in, datetime):
+        t = t_in
+    elif isinstance(t_in, str):
+        t = pd.to_datetime(t_in)
+    else:
+        raise Exception("Illegal type for time (only supporting string and datetime")
+    return t.strftime("%Y-%m-%dT%H:%M:%SZ")
 
 
-def __format_data_table(data, column_dict):
-    if len(data) == 0:
-        return data
-
-    return data.rename(columns=column_dict).set_index("t")
+def __format_start_end_time(start_time, end_time):
+    start_time = __format_time(start_time)
+    end_time = __format_time(end_time)
+    return start_time, end_time
 
 
 def __format_data_table_co2_per_area(data):
     column_dict = {
-        "HourUTC": "t",
-        "Co2PerkWh": "co2_intensity",
+        "CO2Emission": "co2_intensity",
         "PriceArea": "price_area",
     }
-    return __format_data_table(data, column_dict=column_dict)
+    return format_to_timetable(data, time_column="Minutes5UTC", column_dict=column_dict)
 
 
 def __format_data_table_co2_per_distribution(data):
     column_dict = {
-        "HourUTC": "t",
         "Co2PerkWh": "co2_intensity",
         "PriceArea": "price_area",
         "Co2PerkWh_200": "co2_intensity_200pc",
     }
-    return __format_data_table(data, column_dict=column_dict)
+    return format_to_timetable(data, time_column="HourUTC", column_dict=column_dict)
 
 
 def electricity_average_co2_intensity(
     area="",
-    start_time=__date2api_format(datetime.now() - timedelta(hours=168)),
-    end_time=__date2api_format(datetime.now()),
+    start_time=datetime.now() - timedelta(hours=168),
+    end_time=datetime.now(),
 ):
 
+    start_time, end_time = __format_start_end_time(start_time, end_time)
+
     if area == "DK1":
         condition2use = """WHERE "PriceArea" = 'DK1' AND"""
 
@@ -105,10 +112,12 @@ def electricity_average_co2_intensity(
 
 def electricity_average_co2_intensity_forecast(
     area="",
-    start_time=__date2api_format(datetime.now()),
-    end_time=__date2api_format(datetime.now() + timedelta(hours=24)),
+    start_time=datetime.now(),
+    end_time=datetime.now() + timedelta(hours=24),
 ):
 
+    start_time, end_time = __format_start_end_time(start_time, end_time)
+
     if area == "DK1":
         condition2use = """WHERE "PriceArea" = 'DK1' AND"""
 
@@ -140,10 +149,12 @@ def electricity_average_co2_intensity_forecast(
 
 
 def electricity_distribution_average_co2_intensity(
-    start_time=__date2api_format(datetime.now() - timedelta(days=365)),
-    end_time=__date2api_format(datetime.now()),
+    start_time=datetime.now() - timedelta(days=365),
+    end_time=datetime.now(),
 ):
 
+    start_time, end_time = __format_start_end_time(start_time, end_time)
+
     condition2use = """WHERE "HourUTC">='{}' AND "HourUTC"<='{}' """.format(
         start_time, end_time
     )
@@ -162,10 +173,12 @@ def electricity_distribution_average_co2_intensity(
 
 def electricity_balance(
     area="",
-    start_time=__date2api_format(datetime.now() - timedelta(days=15)),
-    end_time=__date2api_format(datetime.now()),
+    start_time=datetime.now() - timedelta(days=15),
+    end_time=datetime.now(),
 ):
 
+    start_time, end_time = __format_start_end_time(start_time, end_time)
+
     if area == "DK1":
         condition2use = """ "PriceArea" = 'DK1' AND"""
 
@@ -190,7 +203,6 @@ def electricity_balance(
     )
 
     dict2use = {
-        "HourUTC": "t",
         "GrossCon": "gross_demand",
         "ElectricBoilerCon": "electric_boiler_demand",
         "NetCon": "net_demand",
@@ -208,15 +220,17 @@ def electricity_balance(
     data = __dk_energinet_dataservice_call(
         sql_query=query2use, output_format="Dataframe"
     )
-    return __format_data_table(data, column_dict=dict2use)
+    return format_to_timetable(data, time_column="HourUTC", column_dict=dict2use)
 
 
 def electricity_production_and_exchange(
     area="",
-    start_time=__date2api_format(datetime.now() - timedelta(days=2)),
-    end_time=__date2api_format(datetime.now()),
+    start_time=datetime.now() - timedelta(days=2),
+    end_time=datetime.now(),
 ):
 
+    start_time, end_time = __format_start_end_time(start_time, end_time)
+
     if area == "DK1":
         condition2use = """ "PriceArea" = 'DK1' AND"""
 
@@ -241,7 +255,6 @@ def electricity_production_and_exchange(
     )
 
     dict2use = {
-        "Minutes5UTC": "t",
         "PriceArea": "price_area",
         "ProductionLt100MW": "generation_under_100MW",
         "ProductionGe100MW": "generation_over_100MW",
@@ -259,15 +272,17 @@ def electricity_production_and_exchange(
     data = __dk_energinet_dataservice_call(
         sql_query=query2use, output_format="Dataframe"
     )
-    return __format_data_table(data, column_dict=dict2use)
+    return format_to_timetable(data, time_column="Minutes5UTC", column_dict=dict2use)
 
 
 def electricity_spot_price(
     area="",
-    start_time=__date2api_format(datetime.now() - timedelta(days=15)),
-    end_time=__date2api_format(datetime.now()),
+    start_time=datetime.now() - timedelta(days=15),
+    end_time=datetime.now(),
 ):
 
+    start_time, end_time = __format_start_end_time(start_time, end_time)
+
     if area == "DK1":
         condition2use = """ "PriceArea" = 'DK1' AND"""
 
@@ -288,7 +303,6 @@ def electricity_spot_price(
     )
 
     dict2use = {
-        "HourUTC": "t",
         "SpotPriceEUR": "spot_price_eur",
         "SpotPriceDKK": "spot_price_dkk",
         "PriceArea": "price_area",
@@ -297,4 +311,4 @@ def electricity_spot_price(
     data = __dk_energinet_dataservice_call(
         sql_query=query2use, output_format="Dataframe"
     )
-    return __format_data_table(data, column_dict=dict2use)
+    return format_to_timetable(data, time_column="HourUTC", column_dict=dict2use)
